@@ -23,8 +23,22 @@ _OS = _get_os()
 def login(platform: str, **kwargs: str) -> Union[str, None]:
     """
     help to log in on dedicated platform
+
+    Args:
+        platform (str): cloud platform name (AWS, GCP, AZURE)
+        **kwargs (str): (optional) additional arguments, currently only `project`
+
+    Returns:
+        Union[str, None]
     """
-    plt(platform, **kwargs)
+    platform = platform.split("=")[-1]
+    try:
+        plt(platform, **kwargs)
+    except TypeError:  # TODO exception occurs in dynacli, try to pass the exception trace here
+        print(
+            "\n------\nMultiple platform references. User the only one."
+            "\ne.g.\n\tclvm login azure\n\tclvm login platform=azure"
+        )
 
     return {
         "AWS": partial(_login_aws, **kwargs),
@@ -35,7 +49,19 @@ def login(platform: str, **kwargs: str) -> Union[str, None]:
 
 # ---
 def _login_aws(**kwargs: str) -> None:
-    pass
+    profile_name = kwargs.get("profile", "default")
+    print(
+        f'\n------\nPlease, fix your AWS credentials and back again. Profile name "{profile_name}"\n'
+    )
+    subprocess.run(
+        [
+            "aws.exe" if _OS == "Windows" else "aws",
+            "configure",
+            f"--profile={profile_name}",
+        ],
+        check=True,
+    )
+    sys.exit(0)
 
 
 # ---
@@ -59,7 +85,8 @@ def _login_gcp(**kwargs: str) -> None:
                     "set",
                     "project",
                     project_id,
-                ]
+                ],
+                check=True,
             )
         else:
             print(
@@ -73,7 +100,8 @@ def _login_gcp(**kwargs: str) -> None:
                 "gcloud.cmd" if _OS == "Windows" else "gcloud",
                 "auth",
                 "login",
-            ]
+            ],
+            check=True,
         )
         subprocess.run(
             [
@@ -81,7 +109,8 @@ def _login_gcp(**kwargs: str) -> None:
                 "auth",
                 "application-default",
                 "login",
-            ]
+            ],
+            check=True,
         )
         if project_id:
             subprocess.run(
@@ -91,7 +120,8 @@ def _login_gcp(**kwargs: str) -> None:
                     "set",
                     "project",
                     project_id,
-                ]
+                ],
+                check=True,
             )
         sys.exit(0)
 
@@ -103,7 +133,8 @@ def _login_azure(**kwargs: str) -> Union[None, Tuple]:
             [
                 "az.cmd" if _OS == "Windows" else "az",
                 "login",
-            ]
+            ],
+            check=True,
         )
         sys.exit(0)
 
@@ -141,7 +172,6 @@ def _login_azure(**kwargs: str) -> Union[None, Tuple]:
 
 # ---
 def _get_config_path(platform: str) -> str:
-    # carrier_os = _get_os()
     _path = ""
 
     if platform == "GCP":
