@@ -1,3 +1,5 @@
+"""clear stored session credentials."""
+
 import os
 
 from pyclvm._common.session_aws import make_file_name
@@ -6,7 +8,7 @@ from pyclvm._common.user_data import get_credentials_file_path
 
 def clear(**kwargs: str) -> None:
     """
-    Clear stored session credentials.
+    clear stored session credentials.
 
     Args:
         **kwargs (str): Provide profile name
